@@ -1,5 +1,5 @@
 import aiohttp
-from urllib.request import urlopen
+from urllib.request import urlopen, Request
 
 url = None
 qq = None
@@ -9,8 +9,10 @@ def convert(num):
 class Country:
 	def __init__(self, country):
 		self.country = country
-		url = f"https://disease.sh/v2/countries/{self.country}"
-		shit = urlopen(url).json()
+		url = f"https://disease.sh/v2/countries/{self.country}"	
+		qq = Request(url)
+		qq.add_header("User-agent", "hsbei3j37dn")
+		shit = urlopen(qq).json()
 		global data
 		data = shit
 	def total_cases(self):
